@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gccv/text.cc 
  *
- * Copyright (C) 2008-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2008-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -351,6 +351,7 @@ Text::Text (Canvas *canvas, double x, double y):
 	m_BlinkSignal (0),
 	m_CursorVisible (false),
 	m_CurPos (0),
+	m_StartSel (0),
 	m_CurTags (NULL),
 	m_Padding (0.),
 	m_Anchor (AnchorLine),
@@ -376,6 +377,7 @@ Text::Text (Group *parent, double x, double y, ItemClient *client):
 	m_BlinkSignal (0),
 	m_CursorVisible (false),
 	m_CurPos (0),
+	m_StartSel (0),
 	m_CurTags (new TextTagList ()),
 	m_Padding (0.),
 	m_Anchor (AnchorLine),
@@ -798,7 +800,7 @@ void Text::InsertTextTag (TextTag *tag, bool rebuild_attributes)
 	std::list <TextTag *> new_tags, invalid;
 	TextTagList::iterator i, iend = m_Tags.end ();
 	TextTag *new_tag;
-	for (i = m_Tags.begin (); i != m_Tags.end (); i++) {
+	for (i = m_Tags.begin (); i != iend; i++) {
 		new_tag = tag->Restrict (*i);
 		if (new_tag)
 			new_tags.push_back (new_tag);
@@ -807,6 +809,7 @@ void Text::InsertTextTag (TextTag *tag, bool rebuild_attributes)
 	}
 	// no remove invalid tags
 	while (!invalid.empty ()) {
+		delete invalid.front ();
 		m_Tags.remove (invalid.front ());
 		invalid.pop_front ();
 	}
