@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.cc 
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -101,6 +101,7 @@ Document::Document (Application *App, bool StandAlone, Window *window):
 	m_bReadOnly = false;
 	SetActive ();
 	m_AllowClipboard = true;
+	m_SoftwareVersion = 0;
 }
 
 Document::~Document ()
@@ -359,7 +360,7 @@ void Document::ExportOB () const
 				Mol.SetTitle ((char*) GetTitle ());
 				Mol.SetDimension (2);
 				for (i = AtomTable.begin (); i != AtomTable.end (); i++) {
-					pgAtom = (Atom*) Ob->GetDescendant ((*i).first.data ());
+					pgAtom = (Atom*) Ob->GetDescendant ((*i).first.c_str ());
 					obAtom.SetIdx ((*i).second);
 					obAtom.SetAtomicNum (pgAtom->GetZ ());
 					pgAtom->GetCoords (&x, &y, &z);
@@ -562,7 +563,11 @@ void Document::AddBond (Bond* pBond)
 			m_pView->Update (pBond);
 		} else {
 			//merge two molecules
-			pMol0->Merge (pMol1);
+			if (pMol1->GetParent () != this) {
+				pMol1->Merge (pMol0);
+				pMol0 = pMol1;
+			} else
+				pMol0->Merge (pMol1);
 		}
 		pMol0->AddBond (pBond);
 	}
@@ -714,6 +719,18 @@ bool Document::Load (xmlNodePtr root)
 		xmlFree (tmp);
 	}
 
+	node = GetNodeByName (root, "generator");
+	if (node) {
+		tmp = reinterpret_cast <char*> (xmlNodeGetContent (node));
+		if (tmp) {
+			char software[strlen (tmp) + 1];
+			unsigned Major = 0, minor = 0, micro = 0, read;
+			if (4 == (read=sscanf (tmp, "%s %u.%u.%u", software, &Major, &minor, &micro)) &&
+			    Major < 1000 && minor < 1000 && micro < 1000)
+				m_SoftwareVersion = Major * 1000000 + minor * 1000 + micro;
+			xmlFree (tmp);
+		}
+	}
 	node = GetNodeByName (root, "title");
 	if (node) {
 		tmp = (char*) xmlNodeGetContent (node);
@@ -767,11 +784,16 @@ bool Document::Load (xmlNodePtr root)
 	while (node) {
 		child = (strcmp ((const char*) node->name, "object"))? node: node->children;
 		pObject = CreateObject ((const char*) child->name, this);
-		if (pObject) {
+		while (pObject) {
 			if (!pObject->Load (child))
 				Remove (pObject);
 			else
 				m_pView->AddObject (pObject);
+			if (child != node) {
+				child = child->next;
+				pObject = (child) ?CreateObject ((const char*) child->name, this): NULL;
+			} else
+				pObject = NULL;
 		}
 		node = node->next;
 	}
@@ -875,7 +897,8 @@ void Document::RemoveAtom (Atom* pAtom)
 	Bond* pBond;
 	while ((pBond = (Bond*) pAtom->GetFirstBond (i)))
 	{
-		if (!m_bUndoRedo && !m_bIsLoading && m_pCurOp)
+		// save only for delete operations since otherwise, the whole group has already been saved
+		if (!m_bUndoRedo && !m_bIsLoading && m_pCurOp && dynamic_cast <DeleteOperation *> (m_pCurOp))
 			m_pCurOp->AddObject (pBond);
 		RemoveBond (pBond);
 	}
@@ -969,6 +992,8 @@ void Document::RemoveBond (Bond* pBond)
 		if ((pAtom1->GetZ () == 6) && (pAtom1->GetBondsNumber () == 0))
 			m_pView->Update (pAtom1);
 		Parent->Lock (false);
+		if (!m_bUndoRedo && !m_bIsLoading && dynamic_cast <ModifyOperation *> (m_pCurOp))
+			m_pCurOp->AddObject (pMol, 1);
 	}
 	m_DirtyObjects.erase (pBond);
 	delete pBond;
@@ -1062,6 +1087,7 @@ void Document::AddObject (Object* pObject)
 	if (m_bIsLoading || m_bUndoRedo)
 		return;
 	if (!m_pCurOp) {
+		// FIXME: this is a bit dangerous and should be removed in the future
 		m_pCurOp = new AddOperation (this, ++m_OpID);
 		m_pCurOp->AddObject (pObject);
 	}
@@ -1227,6 +1253,8 @@ void Document::LoadObjects (xmlNodePtr node)
 		child = GetNextNodeByName (child->next, "bond");
 	}
 	Loaded ();
+	// FIXME: we might just update what needs update, not the whole document
+	m_pView->Update (this);
 }
 
 Operation* Document::GetNewOperation (OperationType type)
@@ -1301,7 +1329,7 @@ double Document::GetYAlign ()
 		WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (GetWidget ()), "data");
 		gccv::Rect rect;
 		pData->GetObjectBounds (this, &rect);
-		return (rect.y1 - rect.y0) / 2.;
+		return (rect.y1 - rect.y0) / 2. / m_Theme->GetZoomFactor ();
 	}
 }
 
@@ -1413,7 +1441,7 @@ double Document::GetMedianBondLength ()
 		}
 	}
 	if (nb > 0)
-		go_range_median_inter_nonconst (lengths.data (), nb, &result);
+		go_range_median_inter_nonconst (&lengths[0], nb, &result);
 	return result;
 }
 
