@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-arrow.cc 
  *
- * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -152,6 +152,7 @@ bool ReactionArrow::Load (xmlNodePtr node)
 		}
 		return true;
 	}
+puts("1");
 	return false;
 }
 
@@ -420,4 +421,9 @@ bool ReactionArrow::SetProperty (unsigned property, char const *value)
 	return true;
 }
 
+std::string ReactionArrow::Name ()
+{
+	return _("Reaction arrow");
+}
+
 }	//	namespace gcp
