@@ -60,7 +60,6 @@ bool Tool::OnClicked (View* pView, Object* pObject, double x, double y, unsigned
 	m_x0 = m_x1 = lastx = x;
 	m_y0 = m_y1 = lasty = y;
 	m_nState = state;
-	m_bPressed = true;
 	m_pObject = pObject;
 	if (pObject)
 		m_pObjectGroup = pObject->GetGroup ();
@@ -69,7 +68,7 @@ bool Tool::OnClicked (View* pView, Object* pObject, double x, double y, unsigned
 	m_pData = (WidgetData*) g_object_get_data (G_OBJECT(m_pWidget), "data");
 	m_dZoomFactor = m_pView->GetZoomFactor ();
 	m_bAllowed = true;
-	return OnClicked ();
+	return (m_bPressed = OnClicked ());
 }
 
 void Tool::OnDrag (double x, double y, unsigned int state)
@@ -93,6 +92,7 @@ void Tool::OnMotion (View* pView, Object* pObject, double x, double y, unsigned
 	m_pData = (WidgetData*) g_object_get_data (G_OBJECT(m_pWidget), "data");
 	m_dZoomFactor = m_pView->GetZoomFactor ();
 	OnMotion ();
+	m_pWidget = NULL;
 }
 
 void Tool::OnLeaveNotify (View* pView, G_GNUC_UNUSED unsigned int state)
@@ -100,6 +100,7 @@ void Tool::OnLeaveNotify (View* pView, G_GNUC_UNUSED unsigned int state)
 	m_pView = pView;
 	m_pData = pView->GetData ();
 	OnLeaveNotify ();
+	m_pWidget = NULL;
 }
 
 void Tool::OnRelease (double x, double y, unsigned int state)
@@ -115,6 +116,7 @@ void Tool::OnRelease (double x, double y, unsigned int state)
 		m_Item = NULL;
 	}
 	m_pObject = NULL;
+	m_pWidget = NULL;
 	m_bChanged = false;
 	m_pView->EnsureSize ();
 }
@@ -143,7 +145,7 @@ bool Tool::Activate (bool bState)
 		return true;
 	} else {
 		if (Deactivate ()) {
-			if (m_pWidget)
+			if (GTK_IS_WIDGET (m_pWidget))
 				gdk_window_set_cursor (gtk_widget_get_parent_window (m_pWidget), NULL);
 			m_pObject = NULL;
 			m_pWidget = NULL;
@@ -196,7 +198,7 @@ void Tool::Activate ()
 
 bool Tool::Deactivate ()
 {
-	return true;
+	return !m_bPressed;
 }
 
 bool Tool::OnKeyPress (G_GNUC_UNUSED GdkEventKey *event)
@@ -231,7 +233,7 @@ bool Tool::CutSelection (G_GNUC_UNUSED GtkClipboard *clipboard)
 
 bool Tool::PasteSelection (G_GNUC_UNUSED GtkClipboard *clipboard)
 {
-	return false;
+	return m_bPressed;
 }
 
 bool Tool::OnReceive (G_GNUC_UNUSED GtkClipboard *clipboard, G_GNUC_UNUSED GtkSelectionData *data, G_GNUC_UNUSED int type)
@@ -241,12 +243,12 @@ bool Tool::OnReceive (G_GNUC_UNUSED GtkClipboard *clipboard, G_GNUC_UNUSED GtkSe
 
 bool Tool::OnUndo ()
 {
-	return false;
+	return m_bPressed;
 }
 
 bool Tool::OnRedo ()
 {
-	return false;
+	return m_bPressed;
 }
 
 void Tool::PushNode (G_GNUC_UNUSED xmlNodePtr node)
