@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * crystalatom.h 
  *
- * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,9 +33,12 @@
 #include <libxml/xmlmemory.h>
 #include <list>
 
+/*!\file*/
 namespace gcu
 {
 
+#define PREC 1e-3
+
 /*! \class CrystalAtom gcu/crystalatom.h
 Used to represent atoms in a crystal.
 */
@@ -97,7 +100,7 @@ Gives the atom the default color.
 @param blue: a pointer to the blue component.
 @param alpha: a pointer to the alpha component.
 
-Used to retreive the color used in the representation of the atom. Mainly useful for user defined
+Used to retrieve the color used in the representation of the atom. Mainly useful for user defined
 colors.
 */
 	void GetColor (double *red, double *green, double *blue, double *alpha);
@@ -178,14 +181,14 @@ than for the whole crystal. If bFixed is true, all atoms are taken into account.
 
 Saves the color and the radius of the atom.
 */
-	virtual bool SaveNode (xmlDocPtr xml, xmlNodePtr node);
+	virtual bool SaveNode (xmlDocPtr xml, xmlNodePtr node) const;
 /*!
 @param node: a pointer to the xmlNode containing the serialized Atom.
 
 Loads the color and the radius of the atom.
 */
 	virtual bool LoadNode (xmlNodePtr node);
-	
+
 protected:
 /*!
 The blue component of the color of the sphere representing the atom.
@@ -218,6 +221,23 @@ not be displayed.
 */
 	int m_nCleave; //0 if not cleaved
 
+/*!
+@param property the identity of the property as defined in objprops.h.
+@param value the value of the property as a string.
+
+Used by the gcu::Loader mechanism to load properties of atoms.
+@return true on success.
+*/
+	bool SetProperty (unsigned property, char const *value);
+
+/*!
+@param property the identity of the property as defined in objprops.h.
+
+Used by the gcu::Loader mechanism to retrieve properties of atoms.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+
 GCU_PROP (double, EffectiveRadiusRatio);
 };
 
