@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/loader.h
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,7 +29,7 @@
 #include <list>
 #include <map>
 #include <string>
-#include <goffice/app/io-context.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-output.h>
 
@@ -200,7 +200,7 @@ This function must be overloaded by a derived class able to read. Default
 implementation just return false.
 @return true on success, false otherwise.
 */
-	virtual ContentType Read (Document *doc, GsfInput *in, char const *mime_type, IOContext *io);
+	virtual ContentType Read (Document *doc, GsfInput *in, char const *mime_type, GOIOContext *io);
 /*!
 @param obj the gcu::Object being written.
 @param out a GsfOutput (see the libgsf documentation at
@@ -213,7 +213,7 @@ This function must be overloaded by a derived class able to write. Default
 implementation just return false.
 @return true on success, false otherwise.
 */
-	virtual bool Write (Object *obj, GsfOutput *out, char const *mime_type, IOContext *io, ContentType type = ContentTypeMisc);
+	virtual bool Write (Object *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type = ContentTypeMisc);
 
 protected:
 /*!
