@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * spectrumview.h
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,8 +24,6 @@
 #define GCU_SPECTRUM_VIEW_H
 
 #include "macros.h"
-#include <goffice/graph/gog-series.h>
-#include <gtk/gtkwidget.h>
 
 /*!\file*/
 namespace gcu
@@ -39,6 +37,7 @@ might change in the future.
 */
 class SpectrumView
 {
+friend class SpectrumViewPrivate;
 public:
 //!Constructor.
 /*!
@@ -167,6 +166,8 @@ GCU_RO_PROP (GtkWidget *, OptionBox)
 @return the first GogSeries* created for the view.
 */
 GCU_RO_PROP (GogSeries *, Series)
+GCU_RO_PROP (int, Width)
+GCU_RO_PROP (int, Height)
 };
 
 }
