@@ -423,7 +423,9 @@ void gcpBondTool::UpdateBond()
 		delete m_Item;
 	if (bond->GetOrder () == 1) {
 		bond->GetLine2DCoords (1, &x1, &y1, &x2, &y2);
-		m_Item = new gccv::Line (m_pView->GetCanvas (), x1, y1, x2, y2);
+		m_Item = new gccv::Line (m_pView->GetCanvas (),
+								 x1 * m_dZoomFactor, y1 * m_dZoomFactor,
+								 x2 * m_dZoomFactor, y2 * m_dZoomFactor);
 		static_cast <LineItem *> (m_Item)->SetLineColor (gcp::AddColor);
 		static_cast <LineItem *> (m_Item)->SetLineWidth (pTheme->GetBondWidth ());
 	} else {
@@ -559,19 +561,35 @@ void gcpUpBondTool::SetType (gcp::Bond* pBond)//FIXME: Is it really useful?
 	pBond->SetType (gcp::UpBondType);
 }
 
+static void on_config_changed (GOConfNode *node, G_GNUC_UNUSED gchar const *key, gcp::Application *app)
+{
+	bool InvertWedgeHashes = go_conf_get_bool (node, "invert-wedge-hashes");
+	GtkWidget *w = app->GetToolItem("DownBond");
+	if (!w)
+		return;
+	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (w), InvertWedgeHashes? "gcp_iDownBond": "gcp_DownBond");
+}
+
 gcpDownBondTool::gcpDownBondTool (gcp::Application *App): gcpBondTool (App, "DownBond", 4)
 {
+	m_ConfNode = go_conf_get_node (App->GetConfDir (), GCP_CONF_DIR_SETTINGS);
+	m_NotificationId = go_conf_add_monitor (m_ConfNode, NULL, (GOConfMonitorFunc) on_config_changed, GetApplication ());
 }
 
 gcpDownBondTool::~gcpDownBondTool ()
 {
+	go_conf_remove_monitor (m_NotificationId);
+	go_conf_free_node (m_ConfNode);
 }
 
 void gcpDownBondTool::Draw()
 {
 	gcp::Theme *pTheme = m_pView->GetDoc ()->GetTheme ();
 	if (m_Item) {
-		static_cast <Hash *> (m_Item)->SetPosition (m_x1, m_y1, m_x0, m_y0);
+		if (gcp::InvertWedgeHashes)
+			static_cast <Hash *> (m_Item)->SetPosition (m_x0, m_y0, m_x1, m_y1);
+		else
+			static_cast <Hash *> (m_Item)->SetPosition (m_x1, m_y1, m_x0, m_y0);
 	} else {
 		gccv::Hash *hash = gcp::InvertWedgeHashes?
 			new Hash (m_pView->GetCanvas (), m_x0, m_y0, m_x1, m_y1, pTheme->GetStereoBondWidth ()):
@@ -616,14 +634,6 @@ void gcpDownBondTool::SetType (gcp::Bond* pBond)
 	pBond->SetType (gcp::DownBondType);
 }
 
-void gcpDownBondTool::OnConfigChanged ()
-{
-	GtkWidget *w = m_pApp->GetToolItem ("DownBond");
-	if (!w)
-		return;
-	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (w), gcp::InvertWedgeHashes? "gcp_iDownBond": "gcp_DownBond");
-}
-
 gcpForeBondTool::gcpForeBondTool (gcp::Application *App): gcpBondTool (App, "ForeBond", 4)
 {
 }
