@@ -49,11 +49,13 @@ public:
 	void OnAddTemplate ();
 	void OnDeleteTemplate ();
 	char const *GetHelpTag () {return "templates";}
+	void OnConfigChanged ();
 
 private:
 	gcpTemplate* m_Template;
 	GtkWidget *m_DeleteBtn;
 	GtkNotebook *m_Book;
+	int m_Width, m_Height;
 };
 
 #endif //GCHEMPAINT_TEMPLATETOOL_H
