@@ -49,6 +49,7 @@ public:
 	bool Deactivate ();
 	void Activate ();
 	bool OnKeyPress (GdkEventKey *event);
+	bool OnKeyRelease (GdkEventKey *event);
 	bool NotifyViewChange ();
 	bool DeleteSelection ();
 	bool CopySelection (GtkClipboard *clipboard);
@@ -84,7 +85,7 @@ private:
 protected:
 	gccv::Text* m_Active;
 	list<xmlNodePtr> m_UndoList, m_RedoList;
-	xmlNodePtr m_CurNode, m_InitNode;
+	xmlNodePtr m_CurNode, m_InitNode, m_GroupNode;
 
 private:
 	bool m_bUndo;
@@ -104,16 +105,17 @@ private:
 	GtkSpinButton *m_RiseButton;
 	bool m_Dirty;
 	gulong m_UnderlineSignal, m_StrikethroughSignal, m_ForeSignal, m_RiseSignal;
+	gcu::Object *m_Group;
 
 GCU_PROP (std::string, FamilyName)
 GCU_PROP (PangoStyle, Style)
 GCU_PROP (PangoWeight, Weight)
 GCU_PROP (PangoStretch, Stretch)
 GCU_PROP (PangoVariant, Variant)
-GCU_PROP (PangoUnderline, Underline)
+GCU_PROP (gccv::TextDecoration, Underline)
 GCU_PROP (int, Size)
 GCU_PROP (int, Rise)
-GCU_PROP (bool, Strikethrough)
+GCU_PROP (gccv::TextDecoration, Strikethrough)
 GCU_PROP (gccv::TextPosition, Position)
 GCU_PROP (GOColor, Color);
 };
