@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/3d/window.cc 
  *
- * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -125,7 +125,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gc3dWindow *window)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChem3D is a molecular structures viewer for Gnome");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2004-2008 Jean Bréfort\n");
+	const gchar * copyright = _("Copyright © 2004-2010 Jean Bréfort\n");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -145,14 +145,14 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gc3dWindow *window)
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (NULL,
-	                       "name", "GChem3D",
+	                       "program-name", "GChem3D",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
@@ -256,6 +256,7 @@ gc3dWindow::gc3dWindow (gc3dApplication *App, gc3dDocument *Doc)
 
 	m_Window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 	gtk_window_set_default_size (m_Window, 250, 280);
+	gtk_window_set_icon_name (m_Window, App->GetIconName ().c_str ());
 	g_signal_connect (G_OBJECT (m_Window), "delete-event", G_CALLBACK (on_delete_event), this);
 
 	vbox = gtk_vbox_new (FALSE, 0);
@@ -295,6 +296,7 @@ gc3dWindow::gc3dWindow (gc3dApplication *App, gc3dDocument *Doc)
 	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 2);
 	bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
+	g_object_unref (ui_manager);
 	m_View = dynamic_cast<gc3dView *> (m_Doc->GetView ());
 	m_View->SetWindow (this);
 	gtk_container_add (GTK_CONTAINER (vbox), m_View->GetWidget ());
