@@ -4,7 +4,7 @@
  * Gnome Crystal
  * document.cc 
  *
- * Copyright (C) 2000-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -37,6 +37,7 @@
 #include "sizedlg.h"
 #include "cleavagesdlg.h"
 #include "globals.h"
+#include <gcu/objprops.h>
 #include <gcu/filechooser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
@@ -45,16 +46,11 @@
 #include <vector>
 #include <map>
 #include <fstream>
+#include <iostream>
 #include <ostream>
 #include <sstream>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
-#ifdef HAVE_OPENBABEL_2_2
-#	include <openbabel/format.h>
-#	include <openbabel/obconversion.h>
-#	include <openbabel/math/matrix3x3.h>
-using namespace OpenBabel;
-#endif
 #include <cstring>
 
 #define SAVE	1
@@ -70,7 +66,6 @@ gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc (pApp)
 {
 	Init ();
 	m_filename = NULL;
-	m_title = NULL;
 	m_bClosing = false;
 	m_ReadOnly = false;
 	m_Author = m_Mail = m_Label = m_Comment = NULL;
@@ -81,7 +76,6 @@ gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc (pApp)
 gcDocument::~gcDocument()
 {
 	g_free(m_filename);
-	g_free(m_title);
 	Reinit();
 	Dialog *dialog;
 	while (!m_Dialogs.empty())
@@ -94,21 +88,42 @@ gcDocument::~gcDocument()
 
 void gcDocument::Define (unsigned nPage)
 {
+	gcu::Dialog *dialog;
 	switch(nPage) {
 	case 0:
-		new gcCellDlg (dynamic_cast <gcApplication *> (m_App), this);
+		dialog = GetDialog ("cell");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcCellDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 1:
-		new gcAtomsDlg (dynamic_cast <gcApplication *> (m_App), this);
+		dialog = GetDialog ("atoms");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcAtomsDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 2:
-		new gcLinesDlg (dynamic_cast <gcApplication *> (m_App), this);
+		dialog = GetDialog ("lines");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcLinesDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 3:
-		new gcSizeDlg (dynamic_cast <gcApplication *> (m_App), this);
+		dialog = GetDialog ("size");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcSizeDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	case 4:
-		new gcCleavagesDlg (dynamic_cast <gcApplication *> (m_App), this);
+		dialog = GetDialog ("cleavages");
+		if (dialog)
+			dialog->Present ();
+		else
+			new gcCleavagesDlg (dynamic_cast <gcApplication *> (m_App), this);
 		break;
 	}
 }
@@ -122,7 +137,10 @@ void gcDocument::Update()
 void gcDocument::UpdateAllViews()
 {
 	list<CrystalView*>::iterator i;
-	for (i = m_Views.begin(); i != m_Views.end(); i++) (*i)->Update();
+	for (i = m_Views.begin(); i != m_Views.end(); i++) {
+		(*i)->Update();
+		static_cast <gcView *> (*i)->GetWindow ()->ClearStatus ();
+	}
 }
 
 void gcDocument::GetSize(gdouble* xmin, gdouble* xmax, gdouble* ymin, gdouble* ymax, gdouble* zmin, gdouble* zmax)
@@ -171,17 +189,20 @@ void gcDocument::SetFileName (const string &filename)
 {
 	GFile *file = g_file_new_for_uri (filename.c_str ());
 	GError *error = NULL;
-	GFileInfo *info = g_file_query_info (file,
-							  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
-							  G_FILE_QUERY_INFO_NONE, NULL, &error);
-	if (error) {
-		g_warning ("GIO error: %s", error->message);
-		g_error_free (error);
-		m_ReadOnly = true;
+	if (g_file_query_exists (file, NULL)) {
+		GFileInfo *info = g_file_query_info (file,
+								  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+								  G_FILE_QUERY_INFO_NONE, NULL, &error);
+		if (error) {
+			g_warning ("GIO error: %s", error->message);
+			g_error_free (error);
+			m_ReadOnly = true;
+		} else
+			m_ReadOnly = !g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+		if (info)
+			g_object_unref (info);
 	} else
-		m_ReadOnly = !g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
-	if (info)
-		g_object_unref (info);
+		m_ReadOnly = false;
 	g_object_unref (file);
 	if (m_filename)
 		g_free (m_filename);
@@ -192,16 +213,11 @@ void gcDocument::SetFileName (const string &filename)
 	int i = filename.length () - 1;
 	while ((m_filename[i] != '/') && (i >= 0))
 		i--;
-	if (i >=0) {
-		m_filename [i] = 0;
-		chdir (m_filename);
-		m_filename[i] = '/';
-	}
 	i++;
 	int j = filename.length () - 1;
 	while ((i < j) && (m_filename[j] != '.'))
 		j--;
-	if (!m_title) {
+	if (m_Title.length () == 0) {
 		g_free (m_Label);
 		char *buf = (strcmp (m_filename + j, ".gcrystal"))? g_strdup (m_filename + i): g_strndup (m_filename + i, j - i);
 		m_Label = g_uri_unescape_string (buf, NULL);
@@ -211,12 +227,18 @@ void gcDocument::SetFileName (const string &filename)
 
 void gcDocument::SetTitle(const gchar* title)
 {
-	g_free(m_title);
-	m_title = g_strdup(title);
+	m_Title = title;
 	g_free(m_Label);
 	m_Label = g_strdup(title);	
 }
 
+void gcDocument::SetTitle (std::string& title)
+{
+	m_Title = title;
+	g_free (m_Label);
+	m_Label = g_strdup (title.c_str ());	
+}
+
 static int cb_xml_to_vfs (GOutputStream *output, const char* buf, int nb)
 {
 	GError *error = NULL;
@@ -247,8 +269,8 @@ void gcDocument::Save() const
 		xmlNewProp (xml->children, (xmlChar*) "revision", (xmlChar*) tmp);
 		xmlNodePtr node;
 
-		if (m_title && *m_title) {
-			node = xmlNewDocNode (xml, NULL, (xmlChar*) "title", (xmlChar*) m_title);
+		if (m_Title.length () > 0) {
+			node = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("title"), reinterpret_cast <xmlChar const *> (m_Title.c_str ()));
 			if (node)
 				xmlAddChild (xml->children, node);
 			else
@@ -317,38 +339,39 @@ void gcDocument::Save() const
 
 void gcDocument::Error (int num) const
 {
-	gchar *mess = NULL;
+	char const *mess = NULL;
 	GtkWidget* message;
 	char *unescaped = g_uri_unescape_string (m_filename, NULL);
 	switch (num) {
 	case SAVE:
-		mess = g_strdup_printf (_("Could not save file\n%s"), unescaped);
+		mess = _("Could not save file\n%s");
 		break;
 	case LOAD:
-		mess = g_strdup_printf (_("Could not load file\n%s"), unescaped);
+		mess = _("Could not load file\n%s");
 		break;
 	case XML:
-		mess = g_strdup_printf (_("%s: invalid xml file.\nTree is empty?"), unescaped);
+		mess = _("%s: invalid xml file.\nTree is empty?");
 		break;
 	case FORMAT:
-		mess = g_strdup_printf (_("%s: invalid file format."), unescaped);
+		mess = _("%s: invalid file format.");
 		break;
 	}
+	message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess, unescaped);
 	g_free (unescaped);
-	message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
 	g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 	gtk_widget_show (message);
-	g_free (mess);
 }
 
 bool gcDocument::Load (const string &filename)
 {
 	xmlDocPtr xml = NULL;
 	gchar *oldfilename, *oldtitle;
+	// close all dialogs
+	ClearDialogs ();
 	if (m_filename)
 		oldfilename = g_strdup (m_filename);
 	else oldfilename = NULL;
-	oldtitle = g_strdup (m_title);
+	oldtitle = g_strdup (m_Title.c_str ());
 	try {
 		if (SetFileName (filename), !m_filename || !m_Label)
 			throw (int) 1;
@@ -440,8 +463,7 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 	if (node) {
 		txt = (char*) xmlNodeGetContent (node);
 		if (txt) {
-			g_free (m_title);
-			m_title = g_strdup (txt);
+			SetTitle (txt);
 			xmlFree (txt);
 		}
 	}
@@ -528,8 +550,10 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 			else if (!strcmp((gchar*)node->name, "atom"))
 			{
 				gcAtom *pAtom = new gcAtom();
-				if (pAtom->LoadOld(node, version)) AtomDef.push_back((CrystalAtom*)pAtom);
-				else delete pAtom;
+				if (pAtom->LoadOld(node, version))
+					AddChild (pAtom);
+				else
+					delete pAtom;
 			}
 			else if (!strcmp((gchar*)node->name, "line"))
 			{
@@ -750,12 +774,11 @@ bool gcDocument::VerifySaved()
 	m_bClosing = true;
 	if (!GetDirty ())
 		return true;
-	gchar* str = g_strdup_printf(_("\"%s\" has been modified.  Do you wish to save it?"), m_Label);
 	GtkWidget* mbox;
 	int res;
 	do
 	{
-		mbox = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+		mbox = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, _("\"%s\" has been modified.  Do you wish to save it?"), m_Label);
 		gtk_dialog_add_button(GTK_DIALOG(mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		res = gtk_dialog_run(GTK_DIALOG(mbox));
 		gtk_widget_destroy(mbox);
@@ -773,7 +796,6 @@ bool gcDocument::VerifySaved()
 	if (res == GTK_RESPONSE_NO)
 		SetDirty (false);
 	else if (res == GTK_RESPONSE_CANCEL) m_bClosing = false;
-	g_free(str);
 	return (res != GTK_RESPONSE_CANCEL);
 }
 
@@ -837,101 +859,6 @@ void gcDocument::RenameViews ()
 	}
 }
 
-#ifdef HAVE_OPENBABEL_2_2
-bool gcDocument::Import (const string &filename, const string& mime_type)
-{
-	gchar *oldfilename, *oldtitle;
-	if (m_filename)
-		oldfilename = g_strdup (m_filename);
-	else oldfilename = NULL;
-	oldtitle = g_strdup (m_title);
-	char *old_num_locale;
-	bool result = false, read_only = false;
-	GFile *file;
-	GFileInfo *info = NULL;
-	GError *error = NULL;
-	try {
-		if (!filename.length ())
-			throw (int) 0;
-		file = g_file_new_for_uri (filename.c_str ());
-		info = g_file_query_info (file,
-								  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","G_FILE_ATTRIBUTE_STANDARD_SIZE,
-								  G_FILE_QUERY_INFO_NONE, NULL, &error);
-		if (error) {
-			g_warning ("GIO error: %s", error->message);
-			g_error_free (error);
-			if (info)
-				g_object_unref (info);
-			g_object_unref (file);
-			throw (int) 1;
-		}
-		gsize size = g_file_info_get_size (info);
-		read_only = !g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
-		g_object_unref (info);
-		if (SetFileName (filename), !m_filename)
-			throw (int) 2;
-		g_free (oldfilename);
-		g_free (oldtitle);
-		char *buf = new char[size + 1];
-		GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
-		gsize n = 0;
-		while (n < size) {
-			n += g_input_stream_read (input, buf, size, NULL, &error);
-			if (error) {
-				g_message ("GIO could not read the file: %s", error->message);
-				g_error_free (error);
-				delete [] buf;
-				g_object_unref (input);
-				g_object_unref (file);
-				throw (int) 3;
-			}
-		}
-		g_object_unref (input);
-		g_object_unref (file);
-		buf[size] = 0;
-		istringstream iss (buf);
-		old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-		setlocale(LC_NUMERIC, "C");
-		OBMol Mol;
-		OBConversion Conv;
-		OBFormat* pInFormat = OBFormat::FormatFromMIME (mime_type.c_str ());
-		if (pInFormat == NULL)
-			throw (int) 4;
-		Conv.SetInFormat (pInFormat);
-		Conv.Read (&Mol, &iss);
-		result = ImportOB (Mol);
-		Mol.Clear ();
-		setlocale (LC_NUMERIC, old_num_locale);
-		g_free (old_num_locale);
-		g_free (buf);
-		if (!result)
-			throw (int) 5;
-		UpdateAllViews ();
-		return true;
-	}
-	catch (int num) {
-		switch (num)
-		{
-		default:
-			Error(LOAD);
-		}
-		if (num >= 0) {
-			if (oldfilename)  {
-				SetFileName (oldfilename);
-				g_free (oldfilename);
-			} else {
-				g_free (m_filename);
-				m_filename = NULL;
-			}
-			SetTitle (oldtitle);
-			g_free (oldtitle);
-		}
-		return false;
-	}
-	return false;
-}
-#endif
-
 void gcDocument::SetAuthor (char const *author)
 {
 	g_free (m_Author);
@@ -955,3 +882,39 @@ void gcDocument::SetLabel (char const *label)
 	g_free (m_Label);
 	m_Label = g_strdup (label);
 }
+
+bool gcDocument::SetProperty (unsigned property, char const *value)
+{
+	switch (property) {
+	case GCU_PROP_DOC_CREATOR:
+		g_free (m_Author);
+		m_Author = g_strdup (value);
+		break;
+	case GCU_PROP_DOC_CREATOR_EMAIL:
+		g_free (m_Mail);
+		m_Mail = g_strdup (value);
+		break;
+	default:
+		return CrystalDoc::SetProperty (property, value);
+	}
+	return true;
+}
+
+std::string gcDocument::GetProperty (unsigned property) const
+{
+	string res;
+	switch (property) {
+	case GCU_PROP_DOC_CREATOR:
+		if (m_Author)
+				 res = m_Author;
+		break;
+	case GCU_PROP_DOC_CREATOR_EMAIL:
+		if (m_Mail)
+				res = m_Mail;
+		g_free (m_Mail);
+		break;
+	default:
+		return CrystalDoc::GetProperty (property);
+	}
+	return res;
+}
